pub struct Bernoulli { /* private fields */ }Expand description
The Bernoulli distribution Bernoulli(p).
This distribution describes a single boolean random variable, which is true
with probability p and false with probability 1 - p.
It is a special case of the Binomial distribution with n = 1.
Plot
The following plot shows the Bernoulli distribution with p = 0.1,
p = 0.5, and p = 0.9.
Example
use rand::distr::{Bernoulli, Distribution};
let d = Bernoulli::new(0.3).unwrap();
let v = d.sample(&mut rand::rng());
println!("{} is from a Bernoulli distribution", v);Precision
This Bernoulli distribution uses 64 bits from the RNG (a u64),
so only probabilities that are multiples of 2-64 can be
represented.
Implementations
Sourceimpl Bernoulli
impl Bernoulli
Sourcepub fn new(p: f64) -> Result<Bernoulli, BernoulliError>
pub fn new(p: f64) -> Result<Bernoulli, BernoulliError>
Construct a new Bernoulli with the given probability of success p.
Precision
For p = 1.0, the resulting distribution will always generate true.
For p = 0.0, the resulting distribution will always generate false.
This method is accurate for any input p in the range [0, 1] which is
a multiple of 2-64. (Note that not all multiples of
2-64 in [0, 1] can be represented as a f64.)
Sourcepub fn from_ratio(
numerator: u32,
denominator: u32,
) -> Result<Bernoulli, BernoulliError>
pub fn from_ratio( numerator: u32, denominator: u32, ) -> Result<Bernoulli, BernoulliError>
Construct a new Bernoulli with the probability of success of
numerator-in-denominator. I.e. from_ratio(2, 3) will return
a Bernoulli with a 2-in-3 chance, or about 67%, of returning true.
For numerator == denominator, the resulting distribution will always
return true; for numerator == 0 it will always return false.
For numerator > denominator or denominator == 0, this returns an
error.
Example
use rand::distr::Bernoulli;
let d = Bernoulli::from_ratio(2, 3).unwrap();
assert!((d.p() - 2.0 / 3.0).abs() < 1e-9);
// Edge cases:
assert_eq!(Bernoulli::from_ratio(3, 3).unwrap().p(), 1.0); // always true
assert_eq!(Bernoulli::from_ratio(0, 3).unwrap().p(), 0.0); // always false
assert!(Bernoulli::from_ratio(4, 3).is_err()); // numerator > denominator
assert!(Bernoulli::from_ratio(1, 0).is_err()); // denominator == 0